import { select } from 'd3';
import { viz } from './viz';
import { data } from '@drbagwell/stat-moving-averages';
import { observeResize } from '@drbagwell/responsive-viz-axes';

export const main = (container, { state, setState }) => {
  const dimensions = observeResize({
    state,
    setState,
    container,
  });

  if (dimensions === null) return;

  const { width, height } = dimensions;

  const svg = select(container)
    .selectAll('svg')
    .data([null])
    .join('svg')
    .attr('width', width)
    .attr('height', height);

  viz(svg, {
    data,
    xValue: (d) => new Date(d.TIMESTAMP),
    xAxisLabelText: 'Time (hours)',
    xAxisLabelOffset: 35,
    yValue: (d) => d.AirTC_1,
    yAxisLabelText: 'Temp (degC)',
    yAxisLabelOffset: 20,
    circleRadius: 500 / 100,
    circleOpacity: 569 / 1000,
    marginTop: 90,
    marginRight: 50,
    marginBottom: 50,
    marginLeft: 50,
    width,
    height,
    innerRectFill: '#B5B5B5',
  });
};
